! ESA (C) 2000-2018 
!
! This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
!
!    SAS is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    (at your option) any later version.
!
!    SAS is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
!+
! Module: exanalyser_mod
!
! Authors:  Richard West - SSC (Leicester)
!          
! Description: Decide whether an exposure should be analysed in the pipeline
! 
! Comments: 
! 
! $Id: module.f90,v 1.6 1998/05/27 13:45:39 gvacanti Exp $
!- 
module exanalyser_mod

  use dal
  use param  
  use errorHandling
  use caloaldefs
  use oal

  implicit none 
  
  private 

  public exanalyser

contains 
  
  !---------------------------------------------------------------------
  subroutine exanalyser
  !---------------------------------------------------------------------

    real, parameter :: minExposure=100.0 ! Minimum exposure

    character (len=5) :: instName
    integer :: inst, dataMode, expID, nExp, oalExpNum, j, dummy,&
         & oalDataMode
    type (ExposureInfoType) :: expInfo
    character (len=1024) :: errString
    real :: expDuration

    ! Fetch parameters
    instName=stringParameter('instrument')
    expID=intParameter('exposureid')

    ! Convert instrument name to internal code
    inst=instID(instName)

    ! Loop though every possible datamode, fetch exposures for this
    ! instrument, looking for the exposure with the ID matching the
    ! input parameter
    oalExpNum=0
    do dataMode=IMAGING, SUMMARY_INFORMATION
       nExp = OAL_selectScope(inst, dataMode)
       do j=1, nExp
          dummy=OAL_selectExposure(j)
          call OAL_exposureInfo(expInfo)
          if(expInfo%number == expID) then
             oalExpNum=j
             oalDatamode=dataMode
          end if
       end do
    end do

    ! Check that the exposure has been found
    if(oalExpNum==0)then
       write(errString,fmt='(A,I3,A)')'Cannot find exposure with ID=',&
            & expID,' for instrument '//instName
       call error('noExposure',trim(errString))
    end if

    ! Retrieve info. about the exposure
    nExp = OAL_selectScope(inst, oalDataMode)
    dummy=OAL_selectExposure(oalExpNum)
    call OAL_exposureInfo(expInfo)

    ! Check exposure length
    expDuration=OAL_ertToTimeTag(expInfo%actualEndTime)-&
         & OAL_ertToTimeTag(expInfo%actualStartTime)
    if(expDuration .lt. minExposure)then
       write(errString,fmt='(A,F5.1,A,F5.1,A)')'Exposure duration (',&
            &expDuration,' seconds) is less than the minimum (',minExposure,&
            &' seconds)'
       call error('badDuration', trim(errString))
    end if

    ! Otherwise everything is OK

  end subroutine exanalyser
  
end module exanalyser_mod
